==> gbook-0.5.tar.bz2: gbook/gbook.i18n-vi.php <==
<?

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2006 Tino Reichardt
 * Copyright (C) 2006 Thanh Vinh Nguyen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "tên",
'f_origin'        => "đến từ",
'f_ip'            => "ip",
'f_browser'       => "trình duyệt",
'f_email'         => "email",
'f_homepage'      => "trang chủ",
'f_captcha'       => "điền chữ số trong hình vào đây",
'f_entry'         => "lời nhắn",
'f_ip'            => "ip",
'f_browser'       => "trình duyệt",

# buttons
'b_submit'        => "gửi đi",
'b_change'        => "thay đổi",
'b_delete'        => "xóa",
'b_reset'         => "làm lại",

# misc
'headline'        => "Guestbook",
'hl_create'       => "Tạo lời nhắn mới:",
'hl_modify'       => "Sửa lời nhắn:",
'new_entry'       => "Chào mừng bạn tới guestbook. Bạn có thể tạo lời nhắn mới [[Special:Guestbook&action=add|'''ở đây''']].",
'entry_okay'      => "Okay, lời nhắn đã được gửi ;)",
'delete_okay'     => "Okay, lời nhắn đã được xóa.",
'change_okay'     => "Okay, lời nhắn đã được sửa.",
'show_entries'    => "Xem lời nhắn.",
'captcha_desc'    => " Điền chữ số trong hình vào đây",
'captcha_fail'    => "Xin lỗi, bạn điền không đúng!",
'err_name'        => "Xin lỗi, bạn phải điền tên!",
'err_entry'       => "Xin lỗi, bạn chưa điền lời nhắn!",
'err_noentry'     => "Xin lỗi, không có lời nhắn này!",
'err_captcha'     => "Xin lỗi, bạn chưa điền chữ số trong hình!"
);

?>

==> gbook-0.6.tar.bz2: gbook/gbook.i18n-vi.php <==
<?

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2006 Tino Reichardt
 * Copyright (C) 2006 Thanh Vinh Nguyen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "tên",
'f_origin'        => "đến từ",
'f_ip'            => "ip",
'f_browser'       => "trình duyệt",
'f_email'         => "email",
'f_homepage'      => "trang chủ",
'f_captcha'       => "điền chữ số trong hình vào đây",
'f_entry'         => "lời nhắn",
'f_ip'            => "ip",
'f_browser'       => "trình duyệt",

# buttons
'b_submit'        => "gửi đi",
'b_change'        => "thay đổi",
'b_delete'        => "xóa",
'b_reset'         => "làm lại",

# misc
'headline'        => "Guestbook",
'hl_create'       => "Tạo lời nhắn mới:",
'hl_modify'       => "Sửa lời nhắn:",
'new_entry'       => "Chào mừng bạn tới guestbook. Bạn có thể tạo lời nhắn mới [{{fullurl:Special:Guestbook|action=add}} '''ở đây'''].",
'entry_okay'      => "Okay, lời nhắn đã được gửi ;)",
'delete_okay'     => "Okay, lời nhắn đã được xóa.",
'change_okay'     => "Okay, lời nhắn đã được sửa.",
'show_entries'    => "Xem lời nhắn.",
'captcha_desc'    => " Điền chữ số trong hình vào đây",
'captcha_fail'    => "Xin lỗi, bạn điền không đúng!",
'err_name'        => "Xin lỗi, bạn phải điền tên!",
'err_entry'       => "Xin lỗi, bạn chưa điền lời nhắn!",
'err_noentry'     => "Xin lỗi, không có lời nhắn này!",
'err_captcha'     => "Xin lỗi, bạn chưa điền chữ số trong hình!"
);

?>
